@@ -238,6 +238,8 @@ def ihdbits_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
             "tags[]": tags,
             }
     scraper=cloudscraper.create_scraper()
+    success_upload=0
+    try_upload=0
     while success_upload==0:
         try_upload+=1
         if try_upload>5:
