@@ -253,6 +253,8 @@ def lemonhd_upload_anime(siteinfo,file1,record_path,qbinfo,basic,hashlist):
         logger.info('已成功填写转载地址')
 
     scraper=cloudscraper.create_scraper()
+    success_upload=0
+    try_upload=0
     while success_upload==0:
         try_upload+=1
         if try_upload>5:
@@ -511,6 +513,8 @@ def lemonhd_upload_tv(siteinfo,file1,record_path,qbinfo,basic,hashlist,up_url):
 
 
     scraper=cloudscraper.create_scraper()
+    success_upload=0
+    try_upload=0
     while success_upload==0:
         try_upload+=1
         if try_upload>5:
